<?php

/**
 * @package ETC_Mods_Bundle
 * @version 1.0.7
 */
/*
Plugin Name: ETC Mods Bundle
Plugin URI: https://wordpress.org/plugins/etc-mods-bundle
Description: Helps developers with three common tasks. This plugin adds a custom admin footer link, a custom login page logo/title/link, and a custom admin dashboard box.
Author: Steve Elliott
Version: 1.0.7
Author URI: https://etczone.com
*/

////////////////////////////
// Add Tables to Database //
////////////////////////////

function etc_mods_bundle_register_settings() {
	$etcadminfooterdata = array(
		'link' => 'https://www.etczone.com',
		'linkText' => 'Site by: Custom Admin Footer Link Text Here',
		'active' => 'true' );
	
	add_option( 'etc_custom_admin_footer_link_option', $etcadminfooterdata, null, 'no' );
	
	$etcadminimgdata = array(
		'imageId' => '',
		'imageLink' => get_home_url(),
		'imageTitle' => get_bloginfo( 'name' ),
		'imageWidth' => '320',
		'active' => 'true' );
	add_option( 'etc_custom_admin_logo_option', $etcadminimgdata, null, 'no' );
	
	$etcadmindashboarddata = array(
		'title' => 'Custom Box Title Here',
		'content' => '<p>Custom Content Here</p>',
		'active' => 'true' );
	add_option( 'etc_custom_admin_dashboard_option', $etcadmindashboarddata, null, 'no' );
	
   register_setting( 'etc_mods_bundle_options_group', 'etc_custom_admin_footer_link_option', 'etc_custom_admin_footer_link_callback' );
   register_setting( 'etc_mods_bundle_options_group', 'etc_custom_admin_logo_option', 'etc_custom_admin_logo_callback' );
   register_setting( 'etc_mods_bundle_options_group', 'etc_custom_admin_dashboard_option', 'etc_custom_admin_dashboard_callback' );
}
add_action( 'admin_init', 'etc_mods_bundle_register_settings' );

///////////////////////////////
// Add Link in Settings Menu //
///////////////////////////////

function etc_mods_bundle_register_options_page() {
  add_options_page('ETC Mods Bundle Settings', 'ETC Mods', 'manage_options', 'ETC-Mods-Bundle', 'etc_mods_bundle_options_page');
}
add_action('admin_menu', 'etc_mods_bundle_register_options_page');



add_action( 'admin_enqueue_scripts', 'load_etc_mods_bundle_admin_styles' );
function load_etc_mods_bundle_admin_styles() {
wp_enqueue_style( 'etc_mods_bundle_css', plugin_dir_url("etc_mods_bundle.php") . 'etc-mods-bundle/css/styles.css', false, '1.0.0' );
} 

///////////////////////////////
// Admin Footer Modification //
///////////////////////////////
$etc_admin_footer_data = get_option("etc_custom_admin_footer_link_option");
if ($etc_admin_footer_data['active'] === "true")
	add_filter('admin_footer_text', 'etc_mods_custom_admin_footer');

function etc_mods_custom_admin_footer ()
{
	$etc_admin_footer_data = get_option("etc_custom_admin_footer_link_option");
    echo '<span id="footer-thankyou"><a href="' . $etc_admin_footer_data['link'] . '" target="_blank">' . $etc_admin_footer_data['linkText'] . '</a></span>';
}

////////////////////////////////////
// Custom Admin Login Header Logo //
////////////////////////////////////
$etc_custom_login_logo_data = get_option("etc_custom_admin_logo_option");
if($etc_custom_login_logo_data['active'] === "true")
	add_action('login_head',  'etc_mods_custom_login_logo');

function etc_mods_custom_login_logo()
{
	$etc_custom_login_logo_data = get_option("etc_custom_admin_logo_option");
	
	 list($width, $height) = getimagesize(wp_get_attachment_image_src($etc_custom_login_logo_data['imageId'], 'medium_large')[0]);
     $newheight = $height * $etc_custom_login_logo_data['imageWidth'] / $width;
	
    echo '<style  type="text/css"> h1 a {  background-image:url(' . wp_get_attachment_image_src($etc_custom_login_logo_data['imageId'], 'medium_large')[0] . ')  !important; background-size: ' . $etc_custom_login_logo_data['imageWidth'] , 'px ' . $newheight . 'px !important; width: ' . $etc_custom_login_logo_data['imageWidth'] . 'px !important; height: ' . $newheight . 'px !important;} </style>';
}

//////////////////////////////////
// Custom Admin Login Logo Link //
//////////////////////////////////
$etc_custom_login_logo_data = get_option("etc_custom_admin_logo_option");
if($etc_custom_login_logo_data['active'] === "true")
	add_filter( 'login_headerurl', 'etc_login_logo_url' );

function etc_login_logo_url() {
	$etc_custom_login_logo_data = get_option("etc_custom_admin_logo_option");
    return $etc_custom_login_logo_data['imageLink'];
}

///////////////////////////////////
// Custom Admin Login Logo Title //
///////////////////////////////////
$etc_custom_login_logo_data = get_option("etc_custom_admin_logo_option");
if($etc_custom_login_logo_data['active'] === "true")
	add_filter( 'login_headertext', 'etc_login_logo_url_title' );
function etc_login_logo_url_title() {
	$etc_custom_login_logo_data = get_option("etc_custom_admin_logo_option");
    return $etc_custom_login_logo_data['imageTitle'];
}

///////////////////////////////////////
// Add JavaScript for Media Selector //
///////////////////////////////////////

$etc_mods_bundle_url =  (isset($_SERVER['HTTPS']) ? 'https' : 'http').'://'.$_SERVER['HTTP_HOST'].$_SERVER['REQUEST_URI'];
if($etc_mods_bundle_url == admin_url() . "options-general.php?page=ETC-Mods-Bundle")
	add_action( 'admin_footer', 'etc_media_selector_print_scripts' );


function etc_media_selector_print_scripts() {
	$etc_saved_attachment_post_id = get_option( 'media_selector_attachment_id', 0 );
	?><script type='text/javascript'>
		jQuery( document ).ready( function( $etc ) {
			// Uploading files
			var etc_file_frame;
			var etc_wp_media_post_id = wp.media.model.settings.post.id; // Store the old id
			var etc_set_to_post_id = <?php echo $etc_saved_attachment_post_id; ?>; // Set this
			jQuery('#etc_upload_image_button').on('click', function( event ){
				event.preventDefault();
				// If the media frame already exists, reopen it.
				if ( etc_file_frame ) {
					// Set the post ID to what we want
					etc_file_frame.uploader.uploader.param( 'post_id', etc_set_to_post_id );
					// Open frame
					etc_file_frame.open();
					return;
				} else {
					// Set the wp.media post id so the uploader grabs the ID we want when initialized
					wp.media.model.settings.post.id = etc_set_to_post_id;
				}
				// Create the media frame.
				etc_file_frame = wp.media.frames.etc_file_frame = wp.media({
					title: 'Select an image to upload',
					button: {
						text: 'Use this image',
					},
					multiple: false	// Set to true to allow multiple files to be selected
				});
				// When an image is selected, run a callback.
				etc_file_frame.on( 'select', function() {
					// We set multiple to false so only get one image from the uploader
					attachment = etc_file_frame.state().get('selection').first().toJSON();
					// Do something with attachment.id and/or attachment.url here
					$etc( '#etc_image-preview' ).attr( 'src', attachment.url ).css( 'width', 'auto' );
					$etc( '#etc_image_attachment_id' ).val( attachment.id );
					// Restore the main post ID
					wp.media.model.settings.post.id = etc_wp_media_post_id;
				});
					// Finally, open the modal
					etc_file_frame.open();
			});
			// Restore the main ID when the add media button is pressed
			jQuery( 'a.add_media' ).on( 'click', function() {
				wp.media.model.settings.post.id = etc_wp_media_post_id;
			});
		});
	</script><?php
}

////////////////////////////////////////
// Add Support Box to Admin Dashboard //
////////////////////////////////////////
$etc_custom_dashboard_support_data = get_option('etc_custom_admin_dashboard_option');
if($etc_custom_dashboard_support_data['active'] === "true")
	add_action('wp_dashboard_setup', 'etc_custom_admin_dashboard_box');

function etc_custom_admin_dashboard_box(){
	$etc_custom_dashboard_support_data = get_option('etc_custom_admin_dashboard_option');
	wp_add_dashboard_widget('custom_help_widget', $etc_custom_dashboard_support_data['title'], 'custom_etc_admin_dashboard_help');
}

function custom_etc_admin_dashboard_help() {
	$etc_custom_dashboard_support_data = get_option('etc_custom_admin_dashboard_option');
	echo $etc_custom_dashboard_support_data['content'];
}

/////////////////////////
// Update After Submit //
/////////////////////////

if(isset($_POST['custom-etc-submit']))
{
	//get values of checkboxes, so a value can be entered.
	if(isset($_POST['etc_custom_footer_text_checkbox']))
		$etcFooterCb = "true";
	else
		$etcFooterCb = "false";
	
		if(isset($_POST['etc_login_logo_checkbox']))
		$etcLoginLogoCb = "true";
	else
		$etcLoginLogoCb = "false";
	
	if(isset($_POST['etc_dashboard_checkbox']))
		$etcDashboardCb = "true";
	else
		$etcDashboardCb = "false";
	
	//Place data back into arrays
	$newdata = array(
		'link' => esc_attr($_POST['footerLink']),
		'linkText' => esc_attr($_POST['footerText'] ),
		'active' => $etcFooterCb );
	
	//Assign value back to image before updating if no new image was selected
	$newimage = $_POST['etc_image_attachment_id'];
	if($newimage == null)
		$newimage = get_option("etc_custom_admin_logo_option")['imageId'];
	
	$newimgdata = array(
		'imageId' => $newimage,
		'imageLink' => esc_attr($_POST['loginLink']),
		'imageTitle' => esc_attr($_POST['loginTitle']),
		'imageWidth' => $_POST['loginImgWidth'],
		'active' => $etcLoginLogoCb );
	
	?>

	<!--save the content to the textarea-->
	<script type="text/javascript">
	var editor = tinymce.get(etc_custom_dashboard_editor);
	editor.save();
	</script><?php
	
	//update dashboard box in database
	$newdashboarddata = array(
		'title' => esc_attr($_POST['dashboardTitle']),
		'content' =>  nl2br($_POST['etc_custom_dashboard_editor']),
		'active' => $etcDashboardCb );
	
	update_option("etc_custom_admin_footer_link_option", $newdata);
	update_option("etc_custom_admin_logo_option", $newimgdata);
	update_option("etc_custom_admin_dashboard_option", $newdashboarddata);
}

////////////////////////
// Build Options Page //
////////////////////////

function etc_mods_bundle_options_page()
{
?>
  <div style="padding-right:1em;">
  <h1>ETC Mods Bundle Settings</h1>
	  <p>This modification bundle contains three typical modifications a WordPress developer would need. Please be sure to click the "Save Changes" button at the bottom of the page after making any changes.</p>
	  <hr />
	  <form method="post" >
		  <?php 
		  @settings_fields( 'etc_mods_bundle_options_group' );
		  @do_settings_fields('ETC-Mods-Bundle','etc_mods_bundle_options_group');
 		  wp_enqueue_media();
		  $etcdbdata = get_option("etc_custom_admin_footer_link_option");
 		  $etcimgdata = get_option("etc_custom_admin_logo_option");
 		  $etcdashboarddata = get_option("etc_custom_admin_dashboard_option");
		  ?>
		  <section>
			  <h3>Admin Footer Link</h3>
			  <p>Edit this section to change the link in the footer of the admin area.</p>
			  <div>
			  	<b><label>Active: </label></b><input type="checkbox" name="etc_custom_footer_text_checkbox" <?php if( $etcdbdata['active'] === "true") { echo "checked"; } ?>>
			  </div>
			  <div>
				<b><label for="etc_custom_footer_text">Text: </label></b>
				<input type="text" id="etc_custom_footer_text" name="footerText" value="<?php echo $etcdbdata['linkText']; ?>" style="width:250px;" />
			  </div>
			  <div>
				<b><label for="etc_custom_footer_link">Link: </label></b>
				<input type="text" id="etc_custom_footer_link" name="footerLink" value="<?php echo $etcdbdata['link']; ?>" style="width:250px;" />
			  </div>
		  </section>
		  <hr />
		  <section>
		  	<h3>Custom Login Page Logo</h3>
			<p>Edit this section to change the logo data that appears on the login page.</p>
			  <div>
			  	<b><label>Active: </label></b><input type="checkbox" name="etc_login_logo_checkbox" <?php if( $etcimgdata['active'] === "true") { echo "checked"; } ?>>
			  </div>
			<div>
				<b><label for="etc_image_preview">Current Image: </label></b><br />
				<?php  
 					if($etcimgdata['imageId'] != null && trim($etcimgdata['imageId']) != ""){
						?><img id='etc_image-preview' src='<?php echo wp_get_attachment_image_src($etcimgdata['imageId'], 'medium')[0] ; ?>' height='100'><?php
					}else{
						?><img id='etc_image-preview' src="<?php echo plugin_dir_url("etc-mods-bundle.php") . 'etc-mods-bundle/images/noimage.jpg'; ?>" height='100'><?php
					}
				?>
			</div>
			<div style="margin-bottom:1em;">
				<input id="etc_upload_image_button" type="button" class="button etc-btn" value="<?php _e( 'Select Image' ); ?>" />
				<input type='hidden' name='etc_image_attachment_id' id='etc_image_attachment_id' value='<?php echo get_option( 'media_selector_attachment_id' ); ?>'>
			</div>
			<div>
			  <b><label>Image Width: </label></b>
			  <input type="number" id="etc_custom_login_img_width" name="loginImgWidth" value="<?php echo $etcimgdata['imageWidth']; ?>" style="width:80px;" required />px <span style="font-size:small; color:#999;">(Number Only)</span>
			</div>
			<div>
			  <b><label for="etc_custom_login_img_title">Title: </label></b>
			  <input type="text" id="etc_custom_login_img_title" name="loginTitle" value="<?php echo $etcimgdata['imageTitle']; ?>" style="width:250px;" />
			</div>
			<div>
			  <b><label for="etc_custom_login_img_link">Link: </label></b>
			  <input type="text" id="etc_custom_login_img_link" name="loginLink" value="<?php echo $etcimgdata['imageLink']; ?>" style="width:250px;" />
			</div>
		  </section>
		  <hr />
		  <section>
		  	<h3>Custom Admin Dashboard Box</h3>
			<p>Edit this section to change the content inside the Dashboard box. <i>This section works great for providing support contact information.</i></p>
			  <div>
			  	<b><label>Active: </label></b><input type="checkbox" name="etc_dashboard_checkbox" <?php if( $etcdashboarddata['active'] === "true") { echo "checked"; } ?>>
			  </div>
			  <div>
				<b><label for="etc_custom_dashboard_title">Title: </label></b>
				<input type="text" id="etc_custom_dashboard_title" name="dashboardTitle" value="<?php echo $etcdashboarddata['title']; ?>" style="width:250px;" />
			  </div>
			  <div>
				<b><label for="etc_custom_dashboard_content">Content: </label></b>
			    <?php 
				  //build editor
				  $editorContent = $etcdashboarddata['content'];
				  $editorId = 'etc_custom_dashboard_editor';
				  wp_editor( $editorContent, $editorId );
			    ?>
			  </div>
		  </section>
		  <hr />
		  <div id="ETCButtonDiv">
			<?php  submit_button('Save Changes', 'primary', 'custom-etc-submit'); ?>
		  </div>
	  </form>
  </div>
<?php
}

//////////////////////////////////////////////
// Add Settings link in the Plugins listing //
//////////////////////////////////////////////
function etc_custom_plugin_add_settings_link( $links ) {
    $settings_link = '<a href="options-general.php?page=ETC-Mods-Bundle">' . __( 'Settings' ) . '</a>';
    array_push( $links, $settings_link );
  	return $links;
}
$plugin = plugin_basename( __FILE__ );
add_filter( "plugin_action_links_$plugin", 'etc_custom_plugin_add_settings_link' );

?>